/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0076
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0076

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const ImplantAssemblyTemplateName(0x0076, 0x0001);
Tag const ImplantAssemblyTemplateIssuer(0x0076, 0x0003);
Tag const ImplantAssemblyTemplateVersion(0x0076, 0x0006);
Tag const ReplacedImplantAssemblyTemplateSequence(0x0076, 0x0008);
Tag const ImplantAssemblyTemplateType(0x0076, 0x000a);
Tag const OriginalImplantAssemblyTemplateSequence(0x0076, 0x000c);
Tag const DerivationImplantAssemblyTemplateSequence(0x0076, 0x000e);
Tag const ImplantAssemblyTemplateTargetAnatomySequence(0x0076, 0x0010);
Tag const ProcedureTypeCodeSequence(0x0076, 0x0020);
Tag const SurgicalTechnique(0x0076, 0x0030);
Tag const ComponentTypesSequence(0x0076, 0x0032);
Tag const ComponentTypeCodeSequence(0x0076, 0x0034);
Tag const ExclusiveComponentType(0x0076, 0x0036);
Tag const MandatoryComponentType(0x0076, 0x0038);
Tag const ComponentSequence(0x0076, 0x0040);
Tag const ComponentID(0x0076, 0x0055);
Tag const ComponentAssemblySequence(0x0076, 0x0060);
Tag const Component1ReferencedID(0x0076, 0x0070);
Tag const Component1ReferencedMatingFeatureSetID(0x0076, 0x0080);
Tag const Component1ReferencedMatingFeatureID(0x0076, 0x0090);
Tag const Component2ReferencedID(0x0076, 0x00a0);
Tag const Component2ReferencedMatingFeatureSetID(0x0076, 0x00b0);
Tag const Component2ReferencedMatingFeatureID(0x0076, 0x00c0);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0076