/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0050
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0050

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const CalibrationImage(0x0050, 0x0004);
Tag const DeviceSequence(0x0050, 0x0010);
Tag const ContainerComponentTypeCodeSequence(0x0050, 0x0012);
Tag const ContainerComponentThickness(0x0050, 0x0013);
Tag const DeviceLength(0x0050, 0x0014);
Tag const ContainerComponentWidth(0x0050, 0x0015);
Tag const DeviceDiameter(0x0050, 0x0016);
Tag const DeviceDiameterUnits(0x0050, 0x0017);
Tag const DeviceVolume(0x0050, 0x0018);
Tag const InterMarkerDistance(0x0050, 0x0019);
Tag const ContainerComponentMaterial(0x0050, 0x001a);
Tag const ContainerComponentID(0x0050, 0x001b);
Tag const ContainerComponentLength(0x0050, 0x001c);
Tag const ContainerComponentDiameter(0x0050, 0x001d);
Tag const ContainerComponentDescription(0x0050, 0x001e);
Tag const DeviceDescription(0x0050, 0x0020);
Tag const LongDeviceDescription(0x0050, 0x0021);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0050