/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0100
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0100

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const SOPInstanceStatus(0x0100, 0x0410);
Tag const SOPAuthorizationDateTime(0x0100, 0x0420);
Tag const SOPAuthorizationComment(0x0100, 0x0424);
Tag const AuthorizationEquipmentCertificationNumber(0x0100, 0x0426);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0100