/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0052
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0052

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const ContrastBolusIngredientPercentByVolume(0x0052, 0x0001);
Tag const OCTFocalDistance(0x0052, 0x0002);
Tag const BeamSpotSize(0x0052, 0x0003);
Tag const EffectiveRefractiveIndex(0x0052, 0x0004);
Tag const OCTAcquisitionDomain(0x0052, 0x0006);
Tag const OCTOpticalCenterWavelength(0x0052, 0x0007);
Tag const AxialResolution(0x0052, 0x0008);
Tag const RangingDepth(0x0052, 0x0009);
Tag const ALineRate(0x0052, 0x0011);
Tag const ALinesPerFrame(0x0052, 0x0012);
Tag const CatheterRotationalRate(0x0052, 0x0013);
Tag const ALinePixelSpacing(0x0052, 0x0014);
Tag const ModeOfPercutaneousAccessSequence(0x0052, 0x0016);
Tag const IntravascularOCTFrameTypeSequence(0x0052, 0x0025);
Tag const OCTZOffsetApplied(0x0052, 0x0026);
Tag const IntravascularFrameContentSequence(0x0052, 0x0027);
Tag const IntravascularLongitudinalDistance(0x0052, 0x0028);
Tag const IntravascularOCTFrameContentSequence(0x0052, 0x0029);
Tag const OCTZOffsetCorrection(0x0052, 0x0030);
Tag const CatheterDirectionOfRotation(0x0052, 0x0031);
Tag const SeamLineLocation(0x0052, 0x0033);
Tag const FirstALineLocation(0x0052, 0x0034);
Tag const SeamLineIndex(0x0052, 0x0036);
Tag const NumberOfPaddedALines(0x0052, 0x0038);
Tag const InterpolationType(0x0052, 0x0039);
Tag const RefractiveIndexApplied(0x0052, 0x003a);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0052