/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_4008
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_4008

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const ResultsID(0x4008, 0x0040);
Tag const ResultsIDIssuer(0x4008, 0x0042);
Tag const ReferencedInterpretationSequence(0x4008, 0x0050);
Tag const ReportProductionStatusTrial(0x4008, 0x00ff);
Tag const InterpretationRecordedDate(0x4008, 0x0100);
Tag const InterpretationRecordedTime(0x4008, 0x0101);
Tag const InterpretationRecorder(0x4008, 0x0102);
Tag const ReferenceToRecordedSound(0x4008, 0x0103);
Tag const InterpretationTranscriptionDate(0x4008, 0x0108);
Tag const InterpretationTranscriptionTime(0x4008, 0x0109);
Tag const InterpretationTranscriber(0x4008, 0x010a);
Tag const InterpretationText(0x4008, 0x010b);
Tag const InterpretationAuthor(0x4008, 0x010c);
Tag const InterpretationApproverSequence(0x4008, 0x0111);
Tag const InterpretationApprovalDate(0x4008, 0x0112);
Tag const InterpretationApprovalTime(0x4008, 0x0113);
Tag const PhysicianApprovingInterpretation(0x4008, 0x0114);
Tag const InterpretationDiagnosisDescription(0x4008, 0x0115);
Tag const InterpretationDiagnosisCodeSequence(0x4008, 0x0117);
Tag const ResultsDistributionListSequence(0x4008, 0x0118);
Tag const DistributionName(0x4008, 0x0119);
Tag const DistributionAddress(0x4008, 0x011a);
Tag const InterpretationID(0x4008, 0x0200);
Tag const InterpretationIDIssuer(0x4008, 0x0202);
Tag const InterpretationTypeID(0x4008, 0x0210);
Tag const InterpretationStatusID(0x4008, 0x0212);
Tag const Impressions(0x4008, 0x0300);
Tag const ResultsComments(0x4008, 0x4000);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_4008