/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0044
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0044

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const ProductPackageIdentifier(0x0044, 0x0001);
Tag const SubstanceAdministrationApproval(0x0044, 0x0002);
Tag const ApprovalStatusFurtherDescription(0x0044, 0x0003);
Tag const ApprovalStatusDateTime(0x0044, 0x0004);
Tag const ProductTypeCodeSequence(0x0044, 0x0007);
Tag const ProductName(0x0044, 0x0008);
Tag const ProductDescription(0x0044, 0x0009);
Tag const ProductLotIdentifier(0x0044, 0x000a);
Tag const ProductExpirationDateTime(0x0044, 0x000b);
Tag const SubstanceAdministrationDateTime(0x0044, 0x0010);
Tag const SubstanceAdministrationNotes(0x0044, 0x0011);
Tag const SubstanceAdministrationDeviceID(0x0044, 0x0012);
Tag const ProductParameterSequence(0x0044, 0x0013);
Tag const SubstanceAdministrationParameterSequence(0x0044, 0x0019);
Tag const ApprovalSequence(0x0044, 0x0100);
Tag const AssertionCodeSequence(0x0044, 0x0101);
Tag const AssertionUID(0x0044, 0x0102);
Tag const AsserterIdentificationSequence(0x0044, 0x0103);
Tag const AssertionDateTime(0x0044, 0x0104);
Tag const AssertionExpirationDateTime(0x0044, 0x0105);
Tag const AssertionComments(0x0044, 0x0106);
Tag const RelatedAssertionSequence(0x0044, 0x0107);
Tag const ReferencedAssertionUID(0x0044, 0x0108);
Tag const ApprovalSubjectSequence(0x0044, 0x0109);
Tag const OrganizationalRoleCodeSequence(0x0044, 0x010a);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0044