/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0034
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0034

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const FlowIdentifierSequence(0x0034, 0x0001);
Tag const FlowIdentifier(0x0034, 0x0002);
Tag const FlowTransferSyntaxUID(0x0034, 0x0003);
Tag const FlowRTPSamplingRate(0x0034, 0x0004);
Tag const SourceIdentifier(0x0034, 0x0005);
Tag const FrameOriginTimestamp(0x0034, 0x0007);
Tag const IncludesImagingSubject(0x0034, 0x0008);
Tag const FrameUsefulnessGroupSequence(0x0034, 0x0009);
Tag const RealTimeBulkDataFlowSequence(0x0034, 0x000a);
Tag const CameraPositionGroupSequence(0x0034, 0x000b);
Tag const IncludesInformation(0x0034, 0x000c);
Tag const TimeOfFrameGroupSequence(0x0034, 0x000d);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0034