/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0066
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0066

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const NumberOfSurfaces(0x0066, 0x0001);
Tag const SurfaceSequence(0x0066, 0x0002);
Tag const SurfaceNumber(0x0066, 0x0003);
Tag const SurfaceComments(0x0066, 0x0004);
Tag const SurfaceProcessing(0x0066, 0x0009);
Tag const SurfaceProcessingRatio(0x0066, 0x000a);
Tag const SurfaceProcessingDescription(0x0066, 0x000b);
Tag const RecommendedPresentationOpacity(0x0066, 0x000c);
Tag const RecommendedPresentationType(0x0066, 0x000d);
Tag const FiniteVolume(0x0066, 0x000e);
Tag const Manifold(0x0066, 0x0010);
Tag const SurfacePointsSequence(0x0066, 0x0011);
Tag const SurfacePointsNormalsSequence(0x0066, 0x0012);
Tag const SurfaceMeshPrimitivesSequence(0x0066, 0x0013);
Tag const NumberOfSurfacePoints(0x0066, 0x0015);
Tag const PointCoordinatesData(0x0066, 0x0016);
Tag const PointPositionAccuracy(0x0066, 0x0017);
Tag const MeanPointDistance(0x0066, 0x0018);
Tag const MaximumPointDistance(0x0066, 0x0019);
Tag const PointsBoundingBoxCoordinates(0x0066, 0x001a);
Tag const AxisOfRotation(0x0066, 0x001b);
Tag const CenterOfRotation(0x0066, 0x001c);
Tag const NumberOfVectors(0x0066, 0x001e);
Tag const VectorDimensionality(0x0066, 0x001f);
Tag const VectorAccuracy(0x0066, 0x0020);
Tag const VectorCoordinateData(0x0066, 0x0021);
Tag const TrianglePointIndexList(0x0066, 0x0023);
Tag const EdgePointIndexList(0x0066, 0x0024);
Tag const VertexPointIndexList(0x0066, 0x0025);
Tag const TriangleStripSequence(0x0066, 0x0026);
Tag const TriangleFanSequence(0x0066, 0x0027);
Tag const LineSequence(0x0066, 0x0028);
Tag const PrimitivePointIndexList(0x0066, 0x0029);
Tag const SurfaceCount(0x0066, 0x002a);
Tag const ReferencedSurfaceSequence(0x0066, 0x002b);
Tag const ReferencedSurfaceNumber(0x0066, 0x002c);
Tag const SegmentSurfaceGenerationAlgorithmIdentificationSequence(0x0066, 0x002d);
Tag const SegmentSurfaceSourceInstanceSequence(0x0066, 0x002e);
Tag const AlgorithmFamilyCodeSequence(0x0066, 0x002f);
Tag const AlgorithmNameCodeSequence(0x0066, 0x0030);
Tag const AlgorithmVersion(0x0066, 0x0031);
Tag const AlgorithmParameters(0x0066, 0x0032);
Tag const FacetSequence(0x0066, 0x0034);
Tag const SurfaceProcessingAlgorithmIdentificationSequence(0x0066, 0x0035);
Tag const AlgorithmName(0x0066, 0x0036);
Tag const RecommendedPointRadius(0x0066, 0x0037);
Tag const RecommendedLineThickness(0x0066, 0x0038);
Tag const LongPrimitivePointIndexList(0x0066, 0x0040);
Tag const LongTrianglePointIndexList(0x0066, 0x0041);
Tag const LongEdgePointIndexList(0x0066, 0x0042);
Tag const LongVertexPointIndexList(0x0066, 0x0043);
Tag const TrackSetSequence(0x0066, 0x0101);
Tag const TrackSequence(0x0066, 0x0102);
Tag const RecommendedDisplayCIELabValueList(0x0066, 0x0103);
Tag const TrackingAlgorithmIdentificationSequence(0x0066, 0x0104);
Tag const TrackSetNumber(0x0066, 0x0105);
Tag const TrackSetLabel(0x0066, 0x0106);
Tag const TrackSetDescription(0x0066, 0x0107);
Tag const TrackSetAnatomicalTypeCodeSequence(0x0066, 0x0108);
Tag const MeasurementsSequence(0x0066, 0x0121);
Tag const TrackSetStatisticsSequence(0x0066, 0x0124);
Tag const FloatingPointValues(0x0066, 0x0125);
Tag const TrackPointIndexList(0x0066, 0x0129);
Tag const TrackStatisticsSequence(0x0066, 0x0130);
Tag const MeasurementValuesSequence(0x0066, 0x0132);
Tag const DiffusionAcquisitionCodeSequence(0x0066, 0x0133);
Tag const DiffusionModelCodeSequence(0x0066, 0x0134);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0066