/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_3006
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_3006

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const StructureSetLabel(0x3006, 0x0002);
Tag const StructureSetName(0x3006, 0x0004);
Tag const StructureSetDescription(0x3006, 0x0006);
Tag const StructureSetDate(0x3006, 0x0008);
Tag const StructureSetTime(0x3006, 0x0009);
Tag const ReferencedFrameOfReferenceSequence(0x3006, 0x0010);
Tag const RTReferencedStudySequence(0x3006, 0x0012);
Tag const RTReferencedSeriesSequence(0x3006, 0x0014);
Tag const ContourImageSequence(0x3006, 0x0016);
Tag const PredecessorStructureSetSequence(0x3006, 0x0018);
Tag const StructureSetROISequence(0x3006, 0x0020);
Tag const ROINumber(0x3006, 0x0022);
Tag const ReferencedFrameOfReferenceUID(0x3006, 0x0024);
Tag const ROIName(0x3006, 0x0026);
Tag const ROIDescription(0x3006, 0x0028);
Tag const ROIDisplayColor(0x3006, 0x002a);
Tag const ROIVolume(0x3006, 0x002c);
Tag const RTRelatedROISequence(0x3006, 0x0030);
Tag const RTROIRelationship(0x3006, 0x0033);
Tag const ROIGenerationAlgorithm(0x3006, 0x0036);
Tag const ROIDerivationAlgorithmIdentificationSequence(0x3006, 0x0037);
Tag const ROIGenerationDescription(0x3006, 0x0038);
Tag const ROIContourSequence(0x3006, 0x0039);
Tag const ContourSequence(0x3006, 0x0040);
Tag const ContourGeometricType(0x3006, 0x0042);
Tag const ContourSlabThickness(0x3006, 0x0044);
Tag const ContourOffsetVector(0x3006, 0x0045);
Tag const NumberOfContourPoints(0x3006, 0x0046);
Tag const ContourNumber(0x3006, 0x0048);
Tag const AttachedContours(0x3006, 0x0049);
Tag const ContourData(0x3006, 0x0050);
Tag const RTROIObservationsSequence(0x3006, 0x0080);
Tag const ObservationNumber(0x3006, 0x0082);
Tag const ReferencedROINumber(0x3006, 0x0084);
Tag const ROIObservationLabel(0x3006, 0x0085);
Tag const RTROIIdentificationCodeSequence(0x3006, 0x0086);
Tag const ROIObservationDescription(0x3006, 0x0088);
Tag const RelatedRTROIObservationsSequence(0x3006, 0x00a0);
Tag const RTROIInterpretedType(0x3006, 0x00a4);
Tag const ROIInterpreter(0x3006, 0x00a6);
Tag const ROIPhysicalPropertiesSequence(0x3006, 0x00b0);
Tag const ROIPhysicalProperty(0x3006, 0x00b2);
Tag const ROIPhysicalPropertyValue(0x3006, 0x00b4);
Tag const ROIElementalCompositionSequence(0x3006, 0x00b6);
Tag const ROIElementalCompositionAtomicNumber(0x3006, 0x00b7);
Tag const ROIElementalCompositionAtomicMassFraction(0x3006, 0x00b8);
Tag const AdditionalRTROIIdentificationCodeSequence(0x3006, 0x00b9);
Tag const FrameOfReferenceRelationshipSequence(0x3006, 0x00c0);
Tag const RelatedFrameOfReferenceUID(0x3006, 0x00c2);
Tag const FrameOfReferenceTransformationType(0x3006, 0x00c4);
Tag const FrameOfReferenceTransformationMatrix(0x3006, 0x00c6);
Tag const FrameOfReferenceTransformationComment(0x3006, 0x00c8);
Tag const PatientLocationCoordinatesSequence(0x3006, 0x00c9);
Tag const PatientLocationCoordinatesCodeSequence(0x3006, 0x00ca);
Tag const PatientSupportPositionSequence(0x3006, 0x00cb);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_3006