/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0040
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0040

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const ScheduledStationAETitle(0x0040, 0x0001);
Tag const ScheduledProcedureStepStartDate(0x0040, 0x0002);
Tag const ScheduledProcedureStepStartTime(0x0040, 0x0003);
Tag const ScheduledProcedureStepEndDate(0x0040, 0x0004);
Tag const ScheduledProcedureStepEndTime(0x0040, 0x0005);
Tag const ScheduledPerformingPhysicianName(0x0040, 0x0006);
Tag const ScheduledProcedureStepDescription(0x0040, 0x0007);
Tag const ScheduledProtocolCodeSequence(0x0040, 0x0008);
Tag const ScheduledProcedureStepID(0x0040, 0x0009);
Tag const StageCodeSequence(0x0040, 0x000a);
Tag const ScheduledPerformingPhysicianIdentificationSequence(0x0040, 0x000b);
Tag const ScheduledStationName(0x0040, 0x0010);
Tag const ScheduledProcedureStepLocation(0x0040, 0x0011);
Tag const PreMedication(0x0040, 0x0012);
Tag const ScheduledProcedureStepStatus(0x0040, 0x0020);
Tag const OrderPlacerIdentifierSequence(0x0040, 0x0026);
Tag const OrderFillerIdentifierSequence(0x0040, 0x0027);
Tag const LocalNamespaceEntityID(0x0040, 0x0031);
Tag const UniversalEntityID(0x0040, 0x0032);
Tag const UniversalEntityIDType(0x0040, 0x0033);
Tag const IdentifierTypeCode(0x0040, 0x0035);
Tag const AssigningFacilitySequence(0x0040, 0x0036);
Tag const AssigningJurisdictionCodeSequence(0x0040, 0x0039);
Tag const AssigningAgencyOrDepartmentCodeSequence(0x0040, 0x003a);
Tag const ScheduledProcedureStepSequence(0x0040, 0x0100);
Tag const ReferencedNonImageCompositeSOPInstanceSequence(0x0040, 0x0220);
Tag const PerformedStationAETitle(0x0040, 0x0241);
Tag const PerformedStationName(0x0040, 0x0242);
Tag const PerformedLocation(0x0040, 0x0243);
Tag const PerformedProcedureStepStartDate(0x0040, 0x0244);
Tag const PerformedProcedureStepStartTime(0x0040, 0x0245);
Tag const PerformedProcedureStepEndDate(0x0040, 0x0250);
Tag const PerformedProcedureStepEndTime(0x0040, 0x0251);
Tag const PerformedProcedureStepStatus(0x0040, 0x0252);
Tag const PerformedProcedureStepID(0x0040, 0x0253);
Tag const PerformedProcedureStepDescription(0x0040, 0x0254);
Tag const PerformedProcedureTypeDescription(0x0040, 0x0255);
Tag const PerformedProtocolCodeSequence(0x0040, 0x0260);
Tag const PerformedProtocolType(0x0040, 0x0261);
Tag const ScheduledStepAttributesSequence(0x0040, 0x0270);
Tag const RequestAttributesSequence(0x0040, 0x0275);
Tag const CommentsOnThePerformedProcedureStep(0x0040, 0x0280);
Tag const PerformedProcedureStepDiscontinuationReasonCodeSequence(0x0040, 0x0281);
Tag const QuantitySequence(0x0040, 0x0293);
Tag const Quantity(0x0040, 0x0294);
Tag const MeasuringUnitsSequence(0x0040, 0x0295);
Tag const BillingItemSequence(0x0040, 0x0296);
Tag const TotalTimeOfFluoroscopy(0x0040, 0x0300);
Tag const TotalNumberOfExposures(0x0040, 0x0301);
Tag const EntranceDose(0x0040, 0x0302);
Tag const ExposedArea(0x0040, 0x0303);
Tag const DistanceSourceToEntrance(0x0040, 0x0306);
Tag const DistanceSourceToSupport(0x0040, 0x0307);
Tag const ExposureDoseSequence(0x0040, 0x030e);
Tag const CommentsOnRadiationDose(0x0040, 0x0310);
Tag const XRayOutput(0x0040, 0x0312);
Tag const HalfValueLayer(0x0040, 0x0314);
Tag const OrganDose(0x0040, 0x0316);
Tag const OrganExposed(0x0040, 0x0318);
Tag const BillingProcedureStepSequence(0x0040, 0x0320);
Tag const FilmConsumptionSequence(0x0040, 0x0321);
Tag const BillingSuppliesAndDevicesSequence(0x0040, 0x0324);
Tag const ReferencedProcedureStepSequence(0x0040, 0x0330);
Tag const PerformedSeriesSequence(0x0040, 0x0340);
Tag const CommentsOnTheScheduledProcedureStep(0x0040, 0x0400);
Tag const ProtocolContextSequence(0x0040, 0x0440);
Tag const ContentItemModifierSequence(0x0040, 0x0441);
Tag const ScheduledSpecimenSequence(0x0040, 0x0500);
Tag const SpecimenAccessionNumber(0x0040, 0x050a);
Tag const ContainerIdentifier(0x0040, 0x0512);
Tag const IssuerOfTheContainerIdentifierSequence(0x0040, 0x0513);
Tag const AlternateContainerIdentifierSequence(0x0040, 0x0515);
Tag const ContainerTypeCodeSequence(0x0040, 0x0518);
Tag const ContainerDescription(0x0040, 0x051a);
Tag const ContainerComponentSequence(0x0040, 0x0520);
Tag const SpecimenSequence(0x0040, 0x0550);
Tag const SpecimenIdentifier(0x0040, 0x0551);
Tag const SpecimenDescriptionSequenceTrial(0x0040, 0x0552);
Tag const SpecimenDescriptionTrial(0x0040, 0x0553);
Tag const SpecimenUID(0x0040, 0x0554);
Tag const AcquisitionContextSequence(0x0040, 0x0555);
Tag const AcquisitionContextDescription(0x0040, 0x0556);
Tag const SpecimenTypeCodeSequence(0x0040, 0x059a);
Tag const SpecimenDescriptionSequence(0x0040, 0x0560);
Tag const IssuerOfTheSpecimenIdentifierSequence(0x0040, 0x0562);
Tag const SpecimenShortDescription(0x0040, 0x0600);
Tag const SpecimenDetailedDescription(0x0040, 0x0602);
Tag const SpecimenPreparationSequence(0x0040, 0x0610);
Tag const SpecimenPreparationStepContentItemSequence(0x0040, 0x0612);
Tag const SpecimenLocalizationContentItemSequence(0x0040, 0x0620);
Tag const SlideIdentifier(0x0040, 0x06fa);
Tag const WholeSlideMicroscopyImageFrameTypeSequence(0x0040, 0x0710);
Tag const ImageCenterPointCoordinatesSequence(0x0040, 0x071a);
Tag const XOffsetInSlideCoordinateSystem(0x0040, 0x072a);
Tag const YOffsetInSlideCoordinateSystem(0x0040, 0x073a);
Tag const ZOffsetInSlideCoordinateSystem(0x0040, 0x074a);
Tag const PixelSpacingSequence(0x0040, 0x08d8);
Tag const CoordinateSystemAxisCodeSequence(0x0040, 0x08da);
Tag const MeasurementUnitsCodeSequence(0x0040, 0x08ea);
Tag const VitalStainCodeSequenceTrial(0x0040, 0x09f8);
Tag const RequestedProcedureID(0x0040, 0x1001);
Tag const ReasonForTheRequestedProcedure(0x0040, 0x1002);
Tag const RequestedProcedurePriority(0x0040, 0x1003);
Tag const PatientTransportArrangements(0x0040, 0x1004);
Tag const RequestedProcedureLocation(0x0040, 0x1005);
Tag const PlacerOrderNumberProcedure(0x0040, 0x1006);
Tag const FillerOrderNumberProcedure(0x0040, 0x1007);
Tag const ConfidentialityCode(0x0040, 0x1008);
Tag const ReportingPriority(0x0040, 0x1009);
Tag const ReasonForRequestedProcedureCodeSequence(0x0040, 0x100a);
Tag const NamesOfIntendedRecipientsOfResults(0x0040, 0x1010);
Tag const IntendedRecipientsOfResultsIdentificationSequence(0x0040, 0x1011);
Tag const ReasonForPerformedProcedureCodeSequence(0x0040, 0x1012);
Tag const RequestedProcedureDescriptionTrial(0x0040, 0x1060);
Tag const PersonIdentificationCodeSequence(0x0040, 0x1101);
Tag const PersonAddress(0x0040, 0x1102);
Tag const PersonTelephoneNumbers(0x0040, 0x1103);
Tag const PersonTelecomInformation(0x0040, 0x1104);
Tag const RequestedProcedureComments(0x0040, 0x1400);
Tag const ReasonForTheImagingServiceRequest(0x0040, 0x2001);
Tag const IssueDateOfImagingServiceRequest(0x0040, 0x2004);
Tag const IssueTimeOfImagingServiceRequest(0x0040, 0x2005);
Tag const PlacerOrderNumberImagingServiceRequestRetired(0x0040, 0x2006);
Tag const FillerOrderNumberImagingServiceRequestRetired(0x0040, 0x2007);
Tag const OrderEnteredBy(0x0040, 0x2008);
Tag const OrderEntererLocation(0x0040, 0x2009);
Tag const OrderCallbackPhoneNumber(0x0040, 0x2010);
Tag const OrderCallbackTelecomInformation(0x0040, 0x2011);
Tag const PlacerOrderNumberImagingServiceRequest(0x0040, 0x2016);
Tag const FillerOrderNumberImagingServiceRequest(0x0040, 0x2017);
Tag const ImagingServiceRequestComments(0x0040, 0x2400);
Tag const ConfidentialityConstraintOnPatientDataDescription(0x0040, 0x3001);
Tag const GeneralPurposeScheduledProcedureStepStatus(0x0040, 0x4001);
Tag const GeneralPurposePerformedProcedureStepStatus(0x0040, 0x4002);
Tag const GeneralPurposeScheduledProcedureStepPriority(0x0040, 0x4003);
Tag const ScheduledProcessingApplicationsCodeSequence(0x0040, 0x4004);
Tag const ScheduledProcedureStepStartDateTime(0x0040, 0x4005);
Tag const MultipleCopiesFlag(0x0040, 0x4006);
Tag const PerformedProcessingApplicationsCodeSequence(0x0040, 0x4007);
Tag const ScheduledProcedureStepExpirationDateTime(0x0040, 0x4008);
Tag const HumanPerformerCodeSequence(0x0040, 0x4009);
Tag const ScheduledProcedureStepModificationDateTime(0x0040, 0x4010);
Tag const ExpectedCompletionDateTime(0x0040, 0x4011);
Tag const ResultingGeneralPurposePerformedProcedureStepsSequence(0x0040, 0x4015);
Tag const ReferencedGeneralPurposeScheduledProcedureStepSequence(0x0040, 0x4016);
Tag const ScheduledWorkitemCodeSequence(0x0040, 0x4018);
Tag const PerformedWorkitemCodeSequence(0x0040, 0x4019);
Tag const InputAvailabilityFlag(0x0040, 0x4020);
Tag const InputInformationSequence(0x0040, 0x4021);
Tag const RelevantInformationSequence(0x0040, 0x4022);
Tag const ReferencedGeneralPurposeScheduledProcedureStepTransactionUID(0x0040, 0x4023);
Tag const ScheduledStationNameCodeSequence(0x0040, 0x4025);
Tag const ScheduledStationClassCodeSequence(0x0040, 0x4026);
Tag const ScheduledStationGeographicLocationCodeSequence(0x0040, 0x4027);
Tag const PerformedStationNameCodeSequence(0x0040, 0x4028);
Tag const PerformedStationClassCodeSequence(0x0040, 0x4029);
Tag const PerformedStationGeographicLocationCodeSequence(0x0040, 0x4030);
Tag const RequestedSubsequentWorkitemCodeSequence(0x0040, 0x4031);
Tag const NonDICOMOutputCodeSequence(0x0040, 0x4032);
Tag const OutputInformationSequence(0x0040, 0x4033);
Tag const ScheduledHumanPerformersSequence(0x0040, 0x4034);
Tag const ActualHumanPerformersSequence(0x0040, 0x4035);
Tag const HumanPerformerOrganization(0x0040, 0x4036);
Tag const HumanPerformerName(0x0040, 0x4037);
Tag const RawDataHandling(0x0040, 0x4040);
Tag const InputReadinessState(0x0040, 0x4041);
Tag const PerformedProcedureStepStartDateTime(0x0040, 0x4050);
Tag const PerformedProcedureStepEndDateTime(0x0040, 0x4051);
Tag const ProcedureStepCancellationDateTime(0x0040, 0x4052);
Tag const OutputDestinationSequence(0x0040, 0x4070);
Tag const DICOMStorageSequence(0x0040, 0x4071);
Tag const STOWRSStorageSequence(0x0040, 0x4072);
Tag const StorageURL(0x0040, 0x4073);
Tag const XDSStorageSequence(0x0040, 0x4074);
Tag const EntranceDoseInmGy(0x0040, 0x8302);
Tag const EntranceDoseDerivation(0x0040, 0x8303);
Tag const ParametricMapFrameTypeSequence(0x0040, 0x9092);
Tag const ReferencedImageRealWorldValueMappingSequence(0x0040, 0x9094);
Tag const RealWorldValueMappingSequence(0x0040, 0x9096);
Tag const PixelValueMappingCodeSequence(0x0040, 0x9098);
Tag const LUTLabel(0x0040, 0x9210);
Tag const RealWorldValueLastValueMapped(0x0040, 0x9211);
Tag const RealWorldValueLUTData(0x0040, 0x9212);
Tag const DoubleFloatRealWorldValueLastValueMapped(0x0040, 0x9213);
Tag const DoubleFloatRealWorldValueFirstValueMapped(0x0040, 0x9214);
Tag const RealWorldValueFirstValueMapped(0x0040, 0x9216);
Tag const QuantityDefinitionSequence(0x0040, 0x9220);
Tag const RealWorldValueIntercept(0x0040, 0x9224);
Tag const RealWorldValueSlope(0x0040, 0x9225);
Tag const FindingsFlagTrial(0x0040, 0xa007);
Tag const RelationshipType(0x0040, 0xa010);
Tag const FindingsSequenceTrial(0x0040, 0xa020);
Tag const FindingsGroupUIDTrial(0x0040, 0xa021);
Tag const ReferencedFindingsGroupUIDTrial(0x0040, 0xa022);
Tag const FindingsGroupRecordingDateTrial(0x0040, 0xa023);
Tag const FindingsGroupRecordingTimeTrial(0x0040, 0xa024);
Tag const FindingsSourceCategoryCodeSequenceTrial(0x0040, 0xa026);
Tag const VerifyingOrganization(0x0040, 0xa027);
Tag const DocumentingOrganizationIdentifierCodeSequenceTrial(0x0040, 0xa028);
Tag const VerificationDateTime(0x0040, 0xa030);
Tag const ObservationDateTime(0x0040, 0xa032);
Tag const ValueType(0x0040, 0xa040);
Tag const ConceptNameCodeSequence(0x0040, 0xa043);
Tag const MeasurementPrecisionDescriptionTrial(0x0040, 0xa047);
Tag const ContinuityOfContent(0x0040, 0xa050);
Tag const UrgencyOrPriorityAlertsTrial(0x0040, 0xa057);
Tag const SequencingIndicatorTrial(0x0040, 0xa060);
Tag const DocumentIdentifierCodeSequenceTrial(0x0040, 0xa066);
Tag const DocumentAuthorTrial(0x0040, 0xa067);
Tag const DocumentAuthorIdentifierCodeSequenceTrial(0x0040, 0xa068);
Tag const IdentifierCodeSequenceTrial(0x0040, 0xa070);
Tag const VerifyingObserverSequence(0x0040, 0xa073);
Tag const ObjectBinaryIdentifierTrial(0x0040, 0xa074);
Tag const VerifyingObserverName(0x0040, 0xa075);
Tag const DocumentingObserverIdentifierCodeSequenceTrial(0x0040, 0xa076);
Tag const AuthorObserverSequence(0x0040, 0xa078);
Tag const ParticipantSequence(0x0040, 0xa07a);
Tag const CustodialOrganizationSequence(0x0040, 0xa07c);
Tag const ParticipationType(0x0040, 0xa080);
Tag const ParticipationDateTime(0x0040, 0xa082);
Tag const ObserverType(0x0040, 0xa084);
Tag const ProcedureIdentifierCodeSequenceTrial(0x0040, 0xa085);
Tag const VerifyingObserverIdentificationCodeSequence(0x0040, 0xa088);
Tag const ObjectDirectoryBinaryIdentifierTrial(0x0040, 0xa089);
Tag const EquivalentCDADocumentSequence(0x0040, 0xa090);
Tag const ReferencedWaveformChannels(0x0040, 0xa0b0);
Tag const DateOfDocumentOrVerbalTransactionTrial(0x0040, 0xa110);
Tag const TimeOfDocumentCreationOrVerbalTransactionTrial(0x0040, 0xa112);
Tag const DateTime(0x0040, 0xa120);
Tag const Date(0x0040, 0xa121);
Tag const Time(0x0040, 0xa122);
Tag const PersonName(0x0040, 0xa123);
Tag const UID(0x0040, 0xa124);
Tag const ReportStatusIDTrial(0x0040, 0xa125);
Tag const TemporalRangeType(0x0040, 0xa130);
Tag const ReferencedSamplePositions(0x0040, 0xa132);
Tag const ReferencedFrameNumbers(0x0040, 0xa136);
Tag const ReferencedTimeOffsets(0x0040, 0xa138);
Tag const ReferencedDateTime(0x0040, 0xa13a);
Tag const TextValue(0x0040, 0xa160);
Tag const FloatingPointValue(0x0040, 0xa161);
Tag const RationalNumeratorValue(0x0040, 0xa162);
Tag const RationalDenominatorValue(0x0040, 0xa163);
Tag const ObservationCategoryCodeSequenceTrial(0x0040, 0xa167);
Tag const ConceptCodeSequence(0x0040, 0xa168);
Tag const BibliographicCitationTrial(0x0040, 0xa16a);
Tag const PurposeOfReferenceCodeSequence(0x0040, 0xa170);
Tag const ObservationUID(0x0040, 0xa171);
Tag const ReferencedObservationUIDTrial(0x0040, 0xa172);
Tag const ReferencedObservationClassTrial(0x0040, 0xa173);
Tag const ReferencedObjectObservationClassTrial(0x0040, 0xa174);
Tag const AnnotationGroupNumber(0x0040, 0xa180);
Tag const ObservationDateTrial(0x0040, 0xa192);
Tag const ObservationTimeTrial(0x0040, 0xa193);
Tag const MeasurementAutomationTrial(0x0040, 0xa194);
Tag const ModifierCodeSequence(0x0040, 0xa195);
Tag const IdentificationDescriptionTrial(0x0040, 0xa224);
Tag const CoordinatesSetGeometricTypeTrial(0x0040, 0xa290);
Tag const AlgorithmCodeSequenceTrial(0x0040, 0xa296);
Tag const AlgorithmDescriptionTrial(0x0040, 0xa297);
Tag const PixelCoordinatesSetTrial(0x0040, 0xa29a);
Tag const MeasuredValueSequence(0x0040, 0xa300);
Tag const NumericValueQualifierCodeSequence(0x0040, 0xa301);
Tag const CurrentObserverTrial(0x0040, 0xa307);
Tag const NumericValue(0x0040, 0xa30a);
Tag const ReferencedAccessionSequenceTrial(0x0040, 0xa313);
Tag const ReportStatusCommentTrial(0x0040, 0xa33a);
Tag const ProcedureContextSequenceTrial(0x0040, 0xa340);
Tag const VerbalSourceTrial(0x0040, 0xa352);
Tag const AddressTrial(0x0040, 0xa353);
Tag const TelephoneNumberTrial(0x0040, 0xa354);
Tag const VerbalSourceIdentifierCodeSequenceTrial(0x0040, 0xa358);
Tag const PredecessorDocumentsSequence(0x0040, 0xa360);
Tag const ReferencedRequestSequence(0x0040, 0xa370);
Tag const PerformedProcedureCodeSequence(0x0040, 0xa372);
Tag const CurrentRequestedProcedureEvidenceSequence(0x0040, 0xa375);
Tag const ReportDetailSequenceTrial(0x0040, 0xa380);
Tag const PertinentOtherEvidenceSequence(0x0040, 0xa385);
Tag const HL7StructuredDocumentReferenceSequence(0x0040, 0xa390);
Tag const ObservationSubjectUIDTrial(0x0040, 0xa402);
Tag const ObservationSubjectClassTrial(0x0040, 0xa403);
Tag const ObservationSubjectTypeCodeSequenceTrial(0x0040, 0xa404);
Tag const CompletionFlag(0x0040, 0xa491);
Tag const CompletionFlagDescription(0x0040, 0xa492);
Tag const VerificationFlag(0x0040, 0xa493);
Tag const ArchiveRequested(0x0040, 0xa494);
Tag const PreliminaryFlag(0x0040, 0xa496);
Tag const ContentTemplateSequence(0x0040, 0xa504);
Tag const IdenticalDocumentsSequence(0x0040, 0xa525);
Tag const ObservationSubjectContextFlagTrial(0x0040, 0xa600);
Tag const ObserverContextFlagTrial(0x0040, 0xa601);
Tag const ProcedureContextFlagTrial(0x0040, 0xa603);
Tag const ContentSequence(0x0040, 0xa730);
Tag const RelationshipSequenceTrial(0x0040, 0xa731);
Tag const RelationshipTypeCodeSequenceTrial(0x0040, 0xa732);
Tag const LanguageCodeSequenceTrial(0x0040, 0xa744);
Tag const TabulatedValuesSequence(0x0040, 0xa801);
Tag const NumberOfTableRows(0x0040, 0xa802);
Tag const NumbeOfTableColumns(0x0040, 0xa803);
Tag const TableRowNumber(0x0040, 0xa804);
Tag const TableColumnNumber(0x0040, 0xa805);
Tag const TableRowDefinitionSequence(0x0040, 0xa806);
Tag const TableColumnDefinitionSequence(0x0040, 0xa807);
Tag const CellValuesSequence(0x0040, 0xa808);
Tag const UniformResourceLocatorTrial(0x0040, 0xa992);
Tag const WaveformAnnotationSequence(0x0040, 0xb020);
Tag const TemplateIdentifier(0x0040, 0xdb00);
Tag const TemplateVersion(0x0040, 0xdb06);
Tag const TemplateLocalVersion(0x0040, 0xdb07);
Tag const TemplateExtensionFlag(0x0040, 0xdb0b);
Tag const TemplateExtensionOrganizationUID(0x0040, 0xdb0c);
Tag const TemplateExtensionCreatorUID(0x0040, 0xdb0d);
Tag const ReferencedContentItemIdentifier(0x0040, 0xdb73);
Tag const HL7InstanceIdentifier(0x0040, 0xe001);
Tag const HL7DocumentEffectiveTime(0x0040, 0xe004);
Tag const HL7DocumentTypeCodeSequence(0x0040, 0xe006);
Tag const DocumentClassCodeSequence(0x0040, 0xe008);
Tag const RetrieveURI(0x0040, 0xe010);
Tag const RetrieveLocationUID(0x0040, 0xe011);
Tag const TypeOfInstances(0x0040, 0xe020);
Tag const DICOMRetrievalSequence(0x0040, 0xe021);
Tag const DICOMMediaRetrievalSequence(0x0040, 0xe022);
Tag const WADORetrievalSequence(0x0040, 0xe023);
Tag const XDSRetrievalSequence(0x0040, 0xe024);
Tag const WADORSRetrievalSequence(0x0040, 0xe025);
Tag const RepositoryUniqueID(0x0040, 0xe030);
Tag const HomeCommunityID(0x0040, 0xe031);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0040